'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _map = require('lodash/collection/map');

var _map2 = _interopRequireDefault(_map);

var _includes = require('lodash/collection/includes');

var _includes2 = _interopRequireDefault(_includes);

var _some = require('lodash/collection/some');

var _some2 = _interopRequireDefault(_some);

var _jsdocUtils = require('./../jsdocUtils');

var _jsdocUtils2 = _interopRequireDefault(_jsdocUtils);

var _iterateJsdoc = require('./../iterateJsdoc');

var _iterateJsdoc2 = _interopRequireDefault(_iterateJsdoc);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var validateParameterNames = undefined,
    validateParameterNamesDeep = undefined;

validateParameterNames = function (functionParameterNames, jsdoc, report) {
    var jsdocParameterNames = undefined;

    jsdocParameterNames = _jsdocUtils2.default.getJsdocParameterNames(jsdoc);

    return (0, _some2.default)(jsdocParameterNames, function (jsdocParameterName, i) {
        var functionParameterName = undefined;

        functionParameterName = functionParameterNames[i];

        if (!functionParameterName) {
            report('@param "' + jsdocParameterName + '" does not match an existing function parameter.');

            return true;
        }

        if (functionParameterName !== jsdocParameterName) {
            report('Expected @param names to be "' + functionParameterNames.join(', ') + '". Got "' + jsdocParameterNames.join(', ') + '".');

            return true;
        }
    });
};

validateParameterNamesDeep = function (functionParameterNames, jsdoc, report) {
    var jsdocParameterNamesDeep = undefined,
        lastRealParameter = undefined,
        parameterCount = undefined;

    parameterCount = -1;

    jsdocParameterNamesDeep = _jsdocUtils2.default.getJsdocParameterNamesDeep(jsdoc);

    return (0, _some2.default)(jsdocParameterNamesDeep, function (jsdocParameterName) {
        var isPropertyPath = undefined;

        isPropertyPath = (0, _includes2.default)(jsdocParameterName, '.');

        if (isPropertyPath) {
            var pathRootNodeName = undefined;

            if (!lastRealParameter) {
                report('@param path declaration ("' + jsdocParameterName + '") appears before any real parameter.');

                return true;
            }

            pathRootNodeName = jsdocParameterName.slice(0, jsdocParameterName.indexOf('.'));

            if (pathRootNodeName !== lastRealParameter) {
                report('@param path declaration ("' + jsdocParameterName + '") root node name ("' + pathRootNodeName + '") does not match previous real parameter name ("' + lastRealParameter + '").');

                return true;
            }
        } else {
            lastRealParameter = jsdocParameterName;
        }
    });
};

exports.default = (0, _iterateJsdoc2.default)(function (functionNode, jsdocNode, jsdoc, report) {
    var functionParameterNames = undefined,
        jsdocParameterNames = undefined,
        jsdocParameterNamesDeep = undefined,
        isError = undefined;

    functionParameterNames = (0, _map2.default)(functionNode.params, 'name');

    isError = validateParameterNames(functionParameterNames, jsdoc, report);

    if (isError) {
        return;
    }

    validateParameterNamesDeep(functionParameterNames, jsdoc, report);
});
module.exports = exports['default'];
//# sourceMappingURL=checkParamNames.js.map
