'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _isBoolean = require('lodash/lang/isBoolean');

var _isBoolean2 = _interopRequireDefault(_isBoolean);

var _some = require('lodash/collection/some');

var _some2 = _interopRequireDefault(_some);

var _jsdocUtils = require('./../jsdocUtils');

var _jsdocUtils2 = _interopRequireDefault(_jsdocUtils);

var _iterateJsdoc = require('./../iterateJsdoc');

var _iterateJsdoc2 = _interopRequireDefault(_iterateJsdoc);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var extractParagraphs = undefined,
    validateDescription = undefined,
    isNewLinePrecededByAPeriod = undefined;

extractParagraphs = function (text) {
    return text.split(/\n\n/);
};

isNewLinePrecededByAPeriod = function (text) {
    var lines = undefined,
        lastLineEndsSentence = undefined;

    lines = text.split('\n');

    return !(0, _some2.default)(lines, function (line) {
        if ((0, _isBoolean2.default)(lastLineEndsSentence) && !lastLineEndsSentence && /^[A-Z]/.test(line)) {
            return true;
        }

        lastLineEndsSentence = /\.$/.test(line);
    });
};

validateDescription = function (description, report) {
    var isError = undefined,
        paragraphs = undefined;

    if (!description) {
        return true;
    }

    paragraphs = extractParagraphs(description);

    return (0, _some2.default)(paragraphs, function (paragraph, i) {
        if (!/^[A-Z]/.test(paragraph)) {
            if (i === 0) {
                report('Description must start with an uppercase character.');
            } else {
                report('Paragraph must start with an uppercase character.');
            }

            return true;
        }

        if (!/\.$/.test(paragraph)) {
            report('Sentence must end with a period.');

            return true;
        }

        if (!isNewLinePrecededByAPeriod(paragraph)) {
            report('A line of text is started with an uppercase character, but preceding line does not end the sentence.');

            return true;
        }
    });
};

exports.default = (0, _iterateJsdoc2.default)(function (functionNode, jsdocNode, jsdoc, report) {
    validateDescription(jsdoc.description, report);
});
module.exports = exports['default'];
//# sourceMappingURL=requireDescriptionCompleteSentence.js.map
